@@ -1,5 +1,5 @@
 # Lab -- Perl laboratory functions for lintian
-# $Id: Lab.pm 399 2005-01-08 22:47:00Z djpig $
+# $Id: Lab.pm 797 2006-12-03 19:07:00Z rra $
 
 # Copyright (C) 1998-2004 Various authors
 #
@@ -16,8 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, you can find it on the World Wide
 # Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
-# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-# MA 02111-1307, USA.
+# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+# MA 02110-1301, USA.
 
 package Lab;
 use strict;
@@ -116,10 +116,14 @@ sub setup_force {
 	}
     }
 
-    # just create empty files
+    # Just create empty files if they don't already exist.  If they do already
+    # exist, we need to keep the old files so that the list-* unpack programs
+    # can analyze what changed.
     for my $pkgtype (qw( binary source udeb )) {
-	_touch("$dir/info/$pkgtype-packages")
-	    or fail("cannot create $pkgtype package list");
+	if (not -f "$dir/info/$pkgtype-packages") {
+	    _touch("$dir/info/$pkgtype-packages")
+		or fail("cannot create $pkgtype package list");
+	}
     }
 
     $self->{dir} = $dir;
